@@ -68,40 +68,41 @@ class expairseq : public basic
 {
 	GINAC_DECLARE_REGISTERED_CLASS(expairseq, basic)
 
-	friend struct print_order;
+	friend class print_order;
+        friend class ex;
 	// other constructors
 public:
 	expairseq(const ex & lh, const ex & rh);
 	expairseq(const exvector & v);
-	expairseq(const epvector & v, ex  oc, bool do_index_renaming = false);
-	expairseq(std::unique_ptr<epvector>, ex  oc, bool do_index_renaming = false);
+	expairseq(const epvector & v, const numeric& oc, bool do_index_renaming = false);
+	expairseq(std::unique_ptr<epvector>, const numeric& oc, bool do_index_renaming = false);
 	
 	// functions overriding virtual functions from base classes
 public:
-	unsigned precedence() const {return 10;}
-	bool info(unsigned inf) const;
-	size_t nops() const;
-	ex op(size_t i) const;
+	unsigned precedence() const override {return 10;}
+	bool info(unsigned inf) const override;
+	size_t nops() const override;
+	const ex op(size_t i) const override;
 	virtual ex stable_op(size_t i) const;
-	ex map(map_function & f) const;
-	ex eval(int level=0) const;
-	ex to_rational(exmap & repl) const;
-	ex to_polynomial(exmap & repl) const;
-	bool match(const ex & pattern, lst & repl_lst) const;
-	ex subs(const exmap & m, unsigned options = 0) const;
-	ex conjugate() const;
+	ex map(map_function & f) const override;
+	ex eval(int level=0) const override;
+	ex to_rational(exmap & repl) const override;
+	ex to_polynomial(exmap & repl) const override;
+	bool match(const ex & pattern, lst & repl_lst) const override;
+	ex subs(const exmap & m, unsigned options = 0) const override;
+	ex conjugate() const override;
 	numeric calc_total_degree() const;
 	virtual const epvector & get_sorted_seq() const;
 protected:
-	bool is_equal_same_type(const basic & other) const;
-	unsigned return_type() const;
-	unsigned calchash() const;
-	ex expand(unsigned options=0) const;
+	bool is_equal_same_type(const basic & other) const override;
+	unsigned return_type() const override;
+	long calchash() const override;
+	ex expand(unsigned options=0) const override;
 	
 	// new virtual functions which can be overridden by derived classes
 protected:
-	virtual ex thisexpairseq(const epvector & v, const ex & oc, bool do_index_renaming = false) const;
-	virtual ex thisexpairseq(std::unique_ptr<epvector> vp, const ex & oc, bool do_index_renaming = false) const;
+	virtual ex thisexpairseq(const epvector & v, const numeric& oc, bool do_index_renaming = false) const;
+	virtual ex thisexpairseq(std::unique_ptr<epvector> vp, const numeric& oc, bool do_index_renaming = false) const;
 	virtual void printseq(const print_context & c, char delim,
 	                      unsigned this_precedence,
 	                      unsigned upper_precedence) const;
@@ -109,20 +110,20 @@ protected:
 	                       unsigned upper_precedence) const;
 	virtual expair split_ex_to_pair(const ex & e) const;
 	virtual expair combine_ex_with_coeff_to_pair(const ex & e,
-	                                             const ex & c) const;
+	                                             const numeric & c) const;
 	virtual expair combine_pair_with_coeff_to_pair(const expair & p,
-	                                               const ex & c) const;
+	                                               const numeric & c) const;
 	virtual ex recombine_pair_to_ex(const expair & p) const;
 	virtual bool expair_needs_further_processing(epp it);
-	virtual ex default_overall_coeff() const;
-	virtual void combine_overall_coeff(const ex & c);
-	virtual void combine_overall_coeff(const ex & c1, const ex & c2);
+	virtual numeric default_overall_coeff() const;
+	virtual void combine_overall_coeff(const numeric & c);
+	virtual void combine_overall_coeff(const numeric & c1, const numeric & c2);
 	virtual bool can_make_flat(const expair & p) const;
 	
 	// non-virtual functions in this class
 protected:
-	void do_print(const print_context & c, unsigned level) const;
-	void do_print_tree(const print_tree & c, unsigned level) const;
+	void do_print(const print_context & c, unsigned level) const override;
+	void do_print_tree(const print_tree & c, unsigned level) const override;
 	void construct_from_2_ex_via_exvector(const ex & lh, const ex & rh);
 	void construct_from_2_ex(const ex & lh, const ex & rh);
 	void construct_from_2_expairseq(const expairseq & s1,
@@ -167,7 +168,7 @@ protected:
 protected:
 	epvector seq;
 	mutable epvector seq_sorted;
-	ex overall_coeff;
+	numeric overall_coeff;
 #if EXPAIRSEQ_USE_HASHTAB
 	epplistvector hashtab;
 	unsigned hashtabsize;
